==> haskell-text-printer-0.5-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-403cGoe6c08KytxWNU4hTL
key: text-printer-0.5-403cGoe6c08KytxWNU4hTL
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Integral Text.Printer.Fractional
abi: ff67f4f150b8e7f42da5b49d4e5ecbda
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-printer-0.5
hs-libraries: HStext-printer-0.5-403cGoe6c08KytxWNU4hTL
depends:
    base-4.9.0.0 bytestring-0.10.8.1 pretty-1.1.3.3
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-latin1-0.3-227Ci4RixWXG6lWZgYn13J
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-AxgFIDpy8hMHcgHGWuxGGe
key: text-printer-0.5-AxgFIDpy8hMHcgHGWuxGGe
license: BSD3
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Integral Text.Printer.Fractional
abi: 458b7f8774facfd7aeecc33beea9d45d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/text-printer-0.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/text-printer-0.5
hs-libraries: HStext-printer-0.5-AxgFIDpy8hMHcgHGWuxGGe
depends:
    base-4.9.0.0 bytestring-0.10.8.1 pretty-1.1.3.3
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-latin1-0.3-Acd4YfiOX484VCt0O5ys5d
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
